:py:mod:`icclim._core.legacy.user_index.calc_operation`
=======================================================

.. py:module:: icclim._core.legacy.user_index.calc_operation

.. autoapi-nested-parse::

   Contain the CalcOperationLike and CalcOperation classes.



Module Contents
---------------

.. py:class:: CalcOperation




   Represent a calculation operation for a user index.


.. py:class:: CalcOperationRegistry




   Registry for CalcOperation instances.
